ComponentMask

Struct ComponentMask 

pub struct ComponentMask(pub u8);
Bitmask tracking which pipeline components completed during a tick.

Tuple Fields

0: u8

Implementations

Source

impl ComponentMask

pub const INGEST: Self

pub const MINCUT: Self

pub const SPECTRAL: Self

pub const EVIDENCE: Self

pub const WITNESS: Self

pub const ALL: Self

pub fn contains(&self, other: Self) -> bool

Returns true if all bits in other are set in self.

pub fn insert(&mut self, other: Self)

Set all bits present in other.